"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CanvasRequestType(str, Enum):
    r"""The type of request for the Canvas Editor."""
    INPAINT = 'INPAINT'
    OUTPAINT = 'OUTPAINT'
    SKETCH2_IMG = 'SKETCH2IMG'
    IMG2_IMG = 'IMG2IMG'
