"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SdVersions(str, Enum):
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""
    V1_5 = 'v1_5'
    V2 = 'v2'
    V3 = 'v3'
    SDXL_0_8 = 'SDXL_0_8'
    SDXL_0_9 = 'SDXL_0_9'
    SDXL_1_0 = 'SDXL_1_0'
    SDXL_LIGHTNING = 'SDXL_LIGHTNING'
